# Welcome to osxmetadata

osxmetadata provides a simple interface to access various metadata about MacOS / OS X files.  Currently supported metadata attributes include tags/keywords, Finder comments, authors, etc.

## Reference

::: osxmetadata.osxmetadata.OSXMetaData
    :members:
    :undoc-members:
